==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/UploadStringCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescriptionMetadata } from "./AsyncCompletedEventArgsDescriptionMetadata";
import { UploadStringCompletedEventArgsDescription } from "./UploadStringCompletedEventArgsDescription";
/**
 * @hidden
 */
export let UploadStringCompletedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class UploadStringCompletedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (UploadStringCompletedEventArgsDescriptionMetadata.a == null) {
                UploadStringCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                UploadStringCompletedEventArgsDescriptionMetadata.c(UploadStringCompletedEventArgsDescriptionMetadata.a);
            }
            if (a.j(UploadStringCompletedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(UploadStringCompletedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AsyncCompletedEventArgsDescriptionMetadata.c(a);
        }
        static d(a) {
            UploadStringCompletedEventArgsDescriptionMetadata.b(a);
            a.aa("UploadStringCompletedEventArgs", () => new UploadStringCompletedEventArgsDescription());
            a.z("UploadStringCompletedEventArgs", UploadStringCompletedEventArgsDescriptionMetadata.a);
        }
    }
    UploadStringCompletedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(UploadStringCompletedEventArgsDescriptionMetadata, 'UploadStringCompletedEventArgsDescriptionMetadata');
    UploadStringCompletedEventArgsDescriptionMetadata.a = null;
    return UploadStringCompletedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/UploadStringCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescriptionMetadata } from "./AsyncCompletedEventArgsDescriptionMetadata";
import { UploadStringCompletedEventArgsDescription } from "./UploadStringCompletedEventArgsDescription";
/**
 * @hidden
 */
export let UploadStringCompletedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class UploadStringCompletedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (UploadStringCompletedEventArgsDescriptionMetadata.a == null) {
                UploadStringCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                UploadStringCompletedEventArgsDescriptionMetadata.c(UploadStringCompletedEventArgsDescriptionMetadata.a);
            }
            if (a.k(UploadStringCompletedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(UploadStringCompletedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AsyncCompletedEventArgsDescriptionMetadata.c(a);
        }
        static d(a) {
            UploadStringCompletedEventArgsDescriptionMetadata.b(a);
            a.ac("UploadStringCompletedEventArgs", () => new UploadStringCompletedEventArgsDescription());
            a.ab("UploadStringCompletedEventArgs", UploadStringCompletedEventArgsDescriptionMetadata.a);
        }
    }
    UploadStringCompletedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(UploadStringCompletedEventArgsDescriptionMetadata, 'UploadStringCompletedEventArgsDescriptionMetadata');
    UploadStringCompletedEventArgsDescriptionMetadata.a = null;
    return UploadStringCompletedEventArgsDescriptionMetadata;
})();
